@@ -4,17 +4,31 @@ import copy
 import json
 import difflib
 import asyncio
+import tomllib
 import platform
 from pathlib import Path
 from datetime import datetime
 from typing import List, Dict, Union
 
 from ..broker import MessageBroker
-from ..aient.src.aient.models import chatgpt
-from ..aient.src.aient.plugins import get_function_call_list, registry
+from ..aient.aient.models import chatgpt
+from ..aient.aient.models.chatgpt import ModelNotFoundError, TaskComplete, RetryFailedError
+from ..aient.aient.plugins import get_function_call_list, registry
 from ..prompt import worker_system_prompt, instruction_system_prompt
 from ..utils import extract_xml_content, get_current_screen_image_message, replace_xml_content, register_mcp_tools, setup_logger
 
+try:
+    from importlib import metadata
+    version = metadata.version("beswarm")
+except metadata.PackageNotFoundError:
+    try:
+        beswarm_dir = Path(__file__).parent.parent.parent
+        with open(beswarm_dir / "pyproject.toml", "rb") as f:
+            pyproject_data = tomllib.load(f)
+            version = pyproject_data["project"]["version"]
+    except FileNotFoundError:
+        version = "unknown"
+
 class BaseAgent:
     """Base class for agents, handling common initialization and disposal."""
     def __init__(self, goal: str, tools_json: List, agent_config: Dict, work_dir: str, cache_messages: Union[bool, List[Dict]], broker: MessageBroker, listen_topic: str, publish_topic: str, status_topic: str, graph_update_topic: str = None):
@@ -76,8 +90,16 @@ class InstructionAgent(BaseAgent):
                 self.goal_diff = '\n'.join(changed_lines).strip()
 
     def get_conversation_history(self, raw_conversation_history: List[Dict]):
-        conversation_history = copy.deepcopy(raw_conversation_history)
 
+        for index, message in enumerate(raw_conversation_history):
+            if message.get("content") and isinstance(message["content"], str):
+                if "<knowledge_graph_tree>" in message["content"] and self.graph_tree:
+                    message["content"] = replace_xml_content(message["content"], "knowledge_graph_tree", self.graph_tree)
+                    raw_conversation_history[index] = message
+                if "\n\nYour message **must** end with [done] to signify the end of your output." in message["content"]:
+                    message["content"] = message["content"].replace("\n\nYour message **must** end with [done] to signify the end of your output.", "")
+
+        conversation_history = copy.deepcopy(raw_conversation_history)
         self.cache_file.write_text(json.dumps(conversation_history, ensure_ascii=False, indent=4), encoding="utf-8")
 
         work_agent_system_prompt = conversation_history.pop(0)
@@ -95,27 +117,16 @@ class InstructionAgent(BaseAgent):
                 conversation_history[0]["content"].append({"type": "text", "text": extracted_content})
 
             for message in conversation_history:
-                if message.get("content") and isinstance(message["content"], str) \
-                and "<knowledge_graph_tree>" in message["content"] and self.graph_tree:
-                    message["content"] = replace_xml_content(message["content"], "knowledge_graph_tree", self.graph_tree)
+                if message.get("content") and isinstance(message["content"], str):
+                    if "<knowledge_graph_tree>" in message["content"] and self.graph_tree:
+                        message["content"] = replace_xml_content(message["content"], "knowledge_graph_tree", self.graph_tree)
 
-        for index, message in enumerate(raw_conversation_history):
-            if message.get("content") and isinstance(message["content"], str) \
-            and "<knowledge_graph_tree>" in message["content"] and self.graph_tree:
-                message["content"] = replace_xml_content(message["content"], "knowledge_graph_tree", self.graph_tree)
-                raw_conversation_history[index] = message
 
         return conversation_history
 
     async def handle_message(self, message: Dict):
         """Receives a worker response, generates the next instruction, and publishes it."""
 
-        if len(message["conversation"]) > 1 and message["conversation"][-2]["role"] == "user" \
-        and "<task_complete_message>" in message["conversation"][-2]["content"]:
-            task_complete_message = extract_xml_content(message["conversation"][-2]["content"], "task_complete_message")
-            self.broker.publish({"status": "finished", "result": task_complete_message}, self.status_topic)
-            return
-
         instruction_prompt = "".join([
                 "</work_agent_conversation_end>\n\n",
                 f"任务目标: {self.goal}\n\n",
@@ -123,7 +134,7 @@ class InstructionAgent(BaseAgent):
                 "在 tag <work_agent_conversation_start>...</work_agent_conversation_end> 之前的对话历史都是工作智能体的对话历史。\n\n",
                 "根据以上对话历史和目标，请生成下一步指令。如果任务已完成，指示工作智能体调用task_complete工具。\n\n",
             ])
-        if self.last_instruction and 'fetch_gpt_response_stream HTTP Error' not in self.last_instruction:
+        if self.last_instruction and "HTTP Error', 'status_code'" not in self.last_instruction:
             instruction_prompt = (
                 f"{instruction_prompt}\n\n"
                 "你生成的指令格式错误，必须把给assistant的指令放在<instructions>...</instructions>标签内。请重新生成格式正确的指令。"
@@ -135,10 +146,15 @@ class InstructionAgent(BaseAgent):
         if "find_and_click_element" in json.dumps(self.tools_json):
             instruction_prompt = await get_current_screen_image_message(instruction_prompt)
 
-        raw_response = await self.agent.ask_async(instruction_prompt)
+        try:
+            raw_response = await self.agent.ask_async(instruction_prompt)
+        except ModelNotFoundError as e:
+            raise Exception(str(e))
+        except RetryFailedError as e:
+            self.logger.error("❌ Commander retry failed, retrying...")
+            self.broker.publish(message, self.error_topic)
+            return
 
-        if "fetch_gpt_response_stream HTTP Error', 'status_code': 404" in raw_response:
-            raise Exception(f"Model: {self.config['engine']} not found!")
         if "'status_code': 413" in raw_response or \
         "'status_code': 400" in raw_response:
             self.broker.publish({"status": "error", "result": "The request body is too long, please try again."}, self.status_topic)
@@ -166,7 +182,7 @@ class InstructionAgent(BaseAgent):
                     "现在开始执行第一步：\n"
                     f"{instruction}"
                 )
-            self.broker.publish({"instruction": instruction, "conversation": message["conversation"]}, self.publish_topic)
+            self.broker.publish({"instruction": instruction + "\n\nYour message **must** end with [done] to signify the end of your output.", "conversation": message["conversation"]}, self.publish_topic)
             self.last_instruction = None
         else:
             self.logger.error("\n❌ 指令智能体生成的指令不符合要求，正在重新生成。")
@@ -203,7 +219,16 @@ class WorkerAgent(BaseAgent):
         instruction = message["instruction"]
         if "find_and_click_element" in json.dumps(self.tools_json):
             instruction = await get_current_screen_image_message(instruction)
-        response = await self.agent.ask_async(instruction)
+
+        try:
+            response = await self.agent.ask_async(instruction)
+        except TaskComplete as e:
+            self.broker.publish({"status": "finished", "result": e.completion_message}, self.status_topic)
+            return
+        except RetryFailedError as e:
+            self.logger.error("❌ Worker retry failed, retrying...")
+            self.broker.publish(message, self.error_topic)
+            return
 
         if response.strip() == '':
             self.logger.error("\n❌ 工作智能体回复为空，请重新生成指令。")
@@ -251,6 +276,7 @@ class BrokerWorker:
         # 创建一个文件处理器，将日志写入任务自己的目录
         log_file_path = cache_dir / "agent.log"
         self.logger = setup_logger(f"task_{self.work_dir.name}", log_file_path)
+        self.logger.info(f"beswarm version: {version}")
         self.logger.info(f"Logger for task '{self.goal}' initialized. Log file: {log_file_path}")
 
     async def _configure_tools(self):
@@ -270,6 +296,7 @@ class BrokerWorker:
     def _task_status_subscriber(self, message: Dict):
         """Subscriber for task status changes."""
         if message.get("status") == "finished":
+            self.logger.info("Task completed: " + message.get("result"))
             self.final_result = message.get("result")
             self.task_completion_event.set()
 
@@ -301,7 +328,8 @@ class BrokerWorker:
                 shell=os.getenv('SHELL', 'Unknown'), current_time=datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                 tools_list=self.tools_json
             ),
-            "print_log": True, "temperature": 0.5, "function_call_max_loop": 100, "logger": self.logger
+            "print_log": True, "temperature": 0.5, "function_call_max_loop": 100, "logger": self.logger,
+            "check_done": True
         }
 
         instruction_agent = InstructionAgent(
