@@ -64,7 +64,6 @@ class BaseAPI:
             self.audio_speech: str = urlunparse(parsed_url[:2] + (before_v1 + "audio/speech",) + ("",) * 3)
 
         if parsed_url.path.endswith("/v1beta") or \
-        parsed_url.path.endswith("/v1") or \
         (parsed_url.netloc == 'generativelanguage.googleapis.com' and "openai/chat/completions" not in parsed_url.path):
             before_v1 = parsed_url.path.split("/v1")[0]
             self.base_url = api_url
@@ -78,7 +77,6 @@ def get_engine(provider, endpoint=None, original_model=""):
     engine = None
     stream = None
     if parsed_url.path.endswith("/v1beta") or \
-    parsed_url.path.endswith("/v1") or \
     (parsed_url.netloc == 'generativelanguage.googleapis.com' and "openai/chat/completions" not in parsed_url.path):
         engine = "gemini"
     elif parsed_url.netloc.rstrip('/').endswith('aiplatform.googleapis.com') or \
@@ -169,7 +167,7 @@ def get_proxy(proxy, client_config = {}):
             }
     return client_config
 
-def update_initial_model(provider):
+async def update_initial_model(provider):
     try:
         engine, stream_mode = get_engine(provider, endpoint=None, original_model="")
         # print("engine", engine, provider)
@@ -181,8 +179,8 @@ def update_initial_model(provider):
             before_v1 = api_url.split("/v1beta")[0]
             url = before_v1 + "/v1beta/models"
             params = {"key": api}
-            with httpx.Client(**client_config) as client:
-                response = client.get(url, params=params)
+            async with httpx.AsyncClient(**client_config) as client:
+                response = await client.get(url, params=params)
 
             original_models = response.json()
             if original_models.get("error"):
@@ -202,11 +200,11 @@ def update_initial_model(provider):
                 headers = {"x-api-key": api, "anthropic-version": "2023-06-01"}
             else:
                 headers = {"Authorization": f"Bearer {api}"}
-            response = httpx.get(
-                endpoint_models_url,
-                headers=headers,
-                **client_config
-            )
+            async with httpx.AsyncClient(**client_config) as client:
+                response = await client.get(
+                    endpoint_models_url,
+                    headers=headers,
+                )
             models = response.json()
             if models.get("error"):
                 logger.error({"error": models.get("error"), "endpoint": endpoint_models_url, "api": api})
