@@ -1,11 +1,13 @@
-from .taskmanager import TaskManager
 from .broker import MessageBroker
 from .bemcp.bemcp import MCPManager
+from .taskmanager import TaskManager
+from .knowledge_graph import KnowledgeGraphManager
 
 """
 全局共享实例
 """
 
-task_manager = TaskManager()
 broker = MessageBroker()
-mcp_manager = MCPManager()
\ No newline at end of file
+mcp_manager = MCPManager()
+task_manager = TaskManager()
+kgm = KnowledgeGraphManager(broker=broker)
\ No newline at end of file
