@@ -5,7 +5,7 @@ import asyncio
 from enum import Enum
 from pathlib import Path
 
-from .aient.src.aient.plugins import registry
+from .aient.aient.plugins import registry
 
 class TaskStatus(Enum):
     """任务状态枚举"""
@@ -23,6 +23,7 @@ class TaskManager:
     它管理任务的生命周期，并通过一个固定大小的工作者池来控制并发执行的任务数量。
     """
     def __init__(self, concurrency_limit=None):
+        self.raw_concurrency_limit = concurrency_limit
         self.concurrency_limit = concurrency_limit or int(os.getenv("BESWARM_CONCURRENCY_LIMIT", "3"))
 
         if self.concurrency_limit <= 0:
@@ -38,8 +39,6 @@ class TaskManager:
         self.cache_dir = None
         self.task_cache_file = None
 
-        print(f"TaskManager 初始化，并发限制为: {self.concurrency_limit}")
-
     def set_root_path(self, root_path):
         """设置工作根目录并加载持久化的任务状态。"""
         if self.root_path is not None:
@@ -52,6 +51,9 @@ class TaskManager:
         self._load_tasks_from_cache()
         self.set_task_cache("root_path", str(self.root_path))
 
+        if not self.raw_concurrency_limit:
+            self.concurrency_limit = int(os.getenv("BESWARM_CONCURRENCY_LIMIT", "3"))
+
         # 启动工作者池
         self.start()
         # 恢复中断的任务
@@ -86,7 +88,6 @@ class TaskManager:
 
     async def _worker_loop(self, worker_name: str):
         """每个工作者的主循环，从队列中拉取并执行任务。"""
-        print(f"[{worker_name}] 已就绪，等待任务...")
         while self._is_running:
             try:
                 task_id, coro = await self._pending_queue.get()
