@@ -4,7 +4,7 @@ import json
 import httpx
 import threading
 
-from ..aient.src.aient.plugins import register_tool, get_url_content # Assuming a similar plugin structure
+from ..aient.aient.plugins import register_tool, get_url_content # Assuming a similar plugin structure
 
 class ThreadWithReturnValue(threading.Thread):
     def run(self):
