@@ -1,7 +1,7 @@
 import ast
 from pathlib import Path
 from ..core import task_manager
-from ..aient.src.aient.plugins import register_tool, registry
+from ..aient.aient.plugins import register_tool, registry
 
 worker_fun = registry.tools["worker"]
 
