@@ -1,7 +1,7 @@
 import csv
 import ast
 import os
-from ..aient.src.aient.plugins import register_tool
+from ..aient.aient.plugins import register_tool
 
 @register_tool()
 def append_row_to_csv(file_path: str, data: list):
